import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/action-menu/vue';
import { iconEllipsis } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/action-menu/index.css';
import Dropdown from '@opentinyvue/vue-dropdown';
import DropdownMenu from '@opentinyvue/vue-dropdown-menu';
import DropdownItem from '@opentinyvue/vue-dropdown-item';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "ActionMenu",
  components: {
    TinyDropdown: Dropdown,
    TinyDropdownMenu: DropdownMenu,
    TinyDropdownItem: DropdownItem,
    TinyIconEllipsis: iconEllipsis()
  },
  emits: ["more-click", "item-click", "visible-change"],
  props: {
    options: {
      type: Array,
      default: function _default() {
        return [];
      }
    },
    maxShowNum: Number,
    moreText: {
      type: String
    },
    spacing: {
      type: [String, Number]
    },
    textField: {
      type: String,
      default: "label"
    },
    popperClass: {
      type: String,
      default: ""
    },
    popperAppendToBody: {
      type: Boolean,
      default: false
    },
    trigger: {
      type: String,
      default: "hover"
    },
    suffixIcon: Object,
    showIcon: {
      type: Boolean,
      default: true
    },
    mode: {
      type: String,
      default: "default"
    }
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-action-menu"
  }, [_c("ul", {
    class: {
      "tiny-action-menu__wrap": true,
      "tiny-action-menu__card-mode": _vm.state.isCardMode
    }
  }, [_vm._l(_vm.state.visibleOptions, function(visibleItem, index) {
    return _c("li", {
      key: index,
      class: ["tiny-action-menu__item", "tiny-action-menu__item-visible", {
        "is-disabled": visibleItem.disabled,
        "tiny-action-menu__card-item": _vm.state.isCardMode
      }]
    }, [_c("tiny-dropdown-item", {
      attrs: {
        "item-data": visibleItem,
        "label": visibleItem[_vm.textField],
        "text-field": _vm.textField,
        "disabled": visibleItem.disabled,
        "icon": visibleItem.icon
      },
      on: {
        "item-click": _vm.handleItemClick
      },
      scopedSlots: _vm._u([{
        key: "default",
        fn: function fn(_ref) {
          var itemData = _ref.itemData;
          return [_vm._t("item", null, {
            "data": itemData
          })];
        }
      }], null, true)
    }), index !== _vm.state.visibleOptions.length - 1 || _vm.state.moreOptions.length ? _c("span", {
      staticClass: "tiny-action-menu__item-line",
      style: {
        margin: "0 " + _vm.state.spacing
      }
    }) : _vm._e()], 1);
  }), _vm.state.moreOptions.length ? _c("li", {
    staticClass: "tiny-action-menu__item"
  }, [_c("tiny-dropdown", {
    attrs: {
      "title": _vm.state.moreText,
      "trigger": _vm.trigger,
      "show-icon": _vm.showIcon
    },
    on: {
      "item-click": _vm.handleItemClick,
      "handle-click": _vm.handleMoreClick,
      "visible-change": _vm.visibleChange
    },
    scopedSlots: _vm._u([_vm.state.suffixIcon ? {
      key: "suffix-icon",
      fn: function fn() {
        return [_c(_vm.state.suffixIcon, {
          tag: "component"
        })];
      },
      proxy: true
    } : null, {
      key: "dropdown",
      fn: function fn() {
        return [_c("tiny-dropdown-menu", {
          attrs: {
            "text-field": _vm.textField,
            "popper-class": _vm.popperClass
          }
        }, _vm._l(_vm.state.moreOptions, function(item, index) {
          return _c("tiny-dropdown-item", {
            key: index,
            attrs: {
              "divided": item.divided,
              "item-data": item,
              "label": item[_vm.textField],
              "disabled": item.disabled
            },
            scopedSlots: _vm._u([{
              key: "default",
              fn: function fn2(_ref2) {
                var itemData = _ref2.itemData;
                return [_vm._t("item", null, {
                  "data": itemData
                })];
              }
            }], null, true)
          });
        }), 1)];
      },
      proxy: true
    }], null, true)
  })], 1) : _vm._e()], 2)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
